package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.ValidDistributeListDTO;
import com.ruoyi.app.domain.DistributeBatch;
import com.ruoyi.app.domain.request.TimeRangeParam;

/**
 * 分销批次Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface DistributeBatchMapper 
{
    /**
     * 查询分销批次
     * 
     * @param id 分销批次主键
     * @return 分销批次
     */
    public DistributeBatch selectDistributeBatchById(Long id);

    /**
     * 查询分销批次列表
     * 
     * @param distributeBatch 分销批次
     * @return 分销批次集合
     */
    public List<DistributeBatch> selectDistributeBatchList(DistributeBatch distributeBatch);

    /**
     * 校验分销批次的肉商是否唯一
     *
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public DistributeBatch checkPurchaserUnique(DistributeBatch distributeBatch);

    /**
     * 获取血码关联的未完成屠宰的分销批次
     *
     * @param slaughterCode 血码
     * @return 结果
     */
    public List<ValidDistributeListDTO> selectValidDistribute(String slaughterCode);

    /**
     * 新增分销批次
     * 
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public int insertDistributeBatch(DistributeBatch distributeBatch);

    /**
     * 批量新增分销批次
     *
     * @param list 分销批次
     * @return 结果
     */
    public int insertDistributeBatchByBatch(List<DistributeBatch> list);

    /**
     * 修改分销批次
     * 
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public int updateDistributeBatch(DistributeBatch distributeBatch);

    /**
     * 删除分销批次
     * 
     * @param id 分销批次主键
     * @return 结果
     */
    public int deleteDistributeBatchById(Long id);

    /**
     * 批量删除分销批次
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDistributeBatchByIds(Long[] ids);

    /**
     * 根据时间获取分销次数
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public Long selectCountByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据时间获取累计屠宰
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public Long selectAmountByTime(TimeRangeParam timeRangeParam);
}
