package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.HookBindBatchListDTO;
import com.ruoyi.app.DTO.HookBindDetailDTO;
import com.ruoyi.app.domain.HookBind;

/**
 * 吊钩绑定Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface HookBindMapper 
{
    /**
     * 查询吊钩绑定
     * 
     * @param batchNo 批次
     * @return 吊钩绑定
     */
    public HookBindBatchListDTO selectHookBindByBatch(String batchNo);

    /**
     * 查询吊钩绑定详情
     *
     * @param hookNo 吊钩号
     * @return 吊钩绑定
     */
    public HookBindDetailDTO selectHookBindDetail(String hookNo);

    /**
     * 查询吊钩绑定列表
     * 
     * @param hookBind 吊钩绑定
     * @return 吊钩绑定集合
     */
    public List<HookBind> selectHookBindList(HookBind hookBind);

    /**
     * 按批次查询吊钩绑定列表
     *
     * @param hookBind 吊钩绑定
     * @return 吊钩绑定集合
     */
    public List<HookBind> selectHookBindListByBatch(HookBind hookBind);

    /**
     * 新增吊钩绑定
     * 
     * @param hookBind 吊钩绑定
     * @return 结果
     */
    public int insertHookBind(HookBind hookBind);

    /**
     * 批量新增吊钩绑定
     *
     * @param list 吊钩绑定
     * @return 结果
     */
    public int insertHookBindBatch(List<HookBind> list);

    /**
     * 校验分销批次的肉商是否唯一
     *
     * @param hookBind 吊钩绑定
     * @return 结果
     */
    public HookBind checkHookNoUnique(HookBind hookBind);

    /**
     * 修改吊钩绑定
     * 
     * @param hookBind 吊钩绑定
     * @return 结果
     */
    public int updateHookBind(HookBind hookBind);

    /**
     * 删除吊钩绑定
     * 
     * @param id 吊钩绑定主键
     * @return 结果
     */
    public int deleteHookBindById(String id);

    /**
     * 批量删除吊钩绑定
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHookBindByIds(String[] ids);
}
