package com.ruoyi.app.mapper;

import java.math.BigDecimal;
import java.util.List;

import com.ruoyi.app.DTO.PorkOtherProduceDTO;
import com.ruoyi.app.domain.PorkOtherProduce;
import com.ruoyi.app.domain.request.ReqGetPorkOtherProduce;
import com.ruoyi.app.domain.request.SearchTimeRangeParam;
import com.ruoyi.app.DTO.TimeAndWeightDTO;
/**
 * 猪头生产记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-19
 */
public interface PorkOtherProduceMapper 
{
    /**
     * 查询猪头生产记录
     * 
     * @param id 猪头生产记录主键
     * @return 猪头生产记录
     */
    public PorkOtherProduceDTO selectPorkOtherProduceById(Long id);

    /**
     * 查询猪头生产记录列表
     * 
     * @param porkSideProduce 猪头生产记录
     * @return 猪头生产记录集合
     */
    public List<PorkOtherProduceDTO> selectPorkOtherProduceList(ReqGetPorkOtherProduce porkSideProduce);

    /**
     * 新增猪头生产记录
     * 
     * @param porkOtherProduce 猪头生产记录
     * @return 结果
     */
    public int insertPorkOtherProduce(PorkOtherProduce porkOtherProduce);

    /**
     * 修改猪头生产记录
     * 
     * @param porkOtherProduce 猪头生产记录
     * @return 结果
     */
    public int updatePorkOtherProduce(PorkOtherProduce porkOtherProduce);

    /**
     * 删除猪头生产记录
     * 
     * @param id 猪头生产记录主键
     * @return 结果
     */
    public int deletePorkOtherProduceById(Long id);

    /**
     * 批量删除猪头生产记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePorkOtherProduceByIds(Long[] ids);

    /**
     * 根据时间获取指定产品平均重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public BigDecimal selectAvgWeightByTime(SearchTimeRangeParam searchTimeRangeParam);

    /**
     * 统计按年全部数据指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectAllYearWeightByTime(SearchTimeRangeParam searchTimeRangeParam);

    /**
     * 根据获取近一年每月指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectYearWeightByTime(SearchTimeRangeParam searchTimeRangeParam);

    /**
     * 根据获取近三十天的每日指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectMonthWeightByTime(SearchTimeRangeParam searchTimeRangeParam);


    /**
     * 根据获取近七天的每日指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectWeekWeightByTime(SearchTimeRangeParam searchTimeRangeParam);

    /**
     * 根据获取每小时指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectTodayWeightByTime(SearchTimeRangeParam searchTimeRangeParam);

    /**
     * 根据获取指定时间范围内每日指定产品累计重量
     *
     * @param searchTimeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectRangeWeightByTime(SearchTimeRangeParam searchTimeRangeParam);
}
