package com.ruoyi.app.mapper;

import java.math.BigDecimal;
import java.util.List;

import com.ruoyi.app.DTO.PorkSideProduceDTO;
import com.ruoyi.app.DTO.TimeAndWeightDTO;
import com.ruoyi.app.domain.PorkSideProduce;
import com.ruoyi.app.domain.request.ReqGetPorkSideProduce;
import com.ruoyi.app.domain.request.TimeRangeParam;
import com.ruoyi.app.domain.request.TimeRangeParam;

/**
 * 白条生产记录Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface PorkSideProduceMapper 
{
    /**
     * 查询白条生产记录
     * 
     * @param id 白条生产记录主键
     * @return 白条生产记录
     */
    public PorkSideProduceDTO selectPorkSideProduceById(Long id);

    /**
     * 查询白条生产记录列表
     * 
     * @param porkSideProduce 白条生产记录
     * @return 白条生产记录集合
     */
    public List<PorkSideProduceDTO> selectPorkSideProduceList(ReqGetPorkSideProduce porkSideProduce);

    /**
     * 新增白条生产记录
     * 
     * @param porkSideProduce 白条生产记录
     * @return 结果
     */
    public int insertPorkSideProduce(PorkSideProduce porkSideProduce);

    /**
     * 修改白条生产记录
     * 
     * @param porkSideProduce 白条生产记录
     * @return 结果
     */
    public int updatePorkSideProduce(PorkSideProduce porkSideProduce);

    /**
     * 删除白条生产记录
     * 
     * @param id 白条生产记录主键
     * @return 结果
     */
    public int deletePorkSideProduceById(Long id);

    /**
     * 批量删除白条生产记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePorkSideProduceByIds(Long[] ids);

    /**
     * 根据时间获取白条平均重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public BigDecimal selectAvgWeightByTime(TimeRangeParam timeRangeParam);

    /**
     * 统计按年全部数据白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectAllYearWeightByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据获取近一年每月白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectYearWeightByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据获取近三十天的每日白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectMonthWeightByTime(TimeRangeParam timeRangeParam);


    /**
     * 根据获取近七天的每日白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectWeekWeightByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据获取每小时白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectTodayWeightByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据获取指定时间范围内每日白条累计重量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<TimeAndWeightDTO> selectRangeWeightByTime(TimeRangeParam timeRangeParam);
}
