package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.PurchaserAmountRankDTO;
import com.ruoyi.app.DTO.PurchaserSaleAmountDTO;
import com.ruoyi.app.DTO.SupplierAmountRankDTO;
import com.ruoyi.app.DTO.SupplierOriginAmountDTO;
import com.ruoyi.app.domain.Purchaser;
import com.ruoyi.app.domain.request.TimeRangeParam;

/**
 * 肉商Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface PurchaserMapper 
{
    /**
     * 查询肉商
     * 
     * @param id 肉商主键
     * @return 肉商
     */
    public Purchaser selectPurchaserById(Long id);

    /**
     * 查询肉商列表
     * 
     * @param purchaser 肉商
     * @return 肉商集合
     */
    public List<Purchaser> selectPurchaserList(Purchaser purchaser);

    /**
     * 查询全部肉商列表
     *
     *
     * @return 肉商集合
     */
    public List<Purchaser> selectPurchaserAll();

    /**
     * 新增肉商
     * 
     * @param purchaser 肉商
     * @return 结果
     */
    public int insertPurchaser(Purchaser purchaser);

    /**
     * 修改肉商
     * 
     * @param purchaser 肉商
     * @return 结果
     */
    public int updatePurchaser(Purchaser purchaser);

    /**
     * 删除肉商
     * 
     * @param id 肉商主键
     * @return 结果
     */
    public int deletePurchaserById(Long id);

    /**
     * 批量删除肉商
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePurchaserByIds(Long[] ids);

    /**
     * 根据时间获取肉商数
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public Long selectCountByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据时间范围获取肉商接收数量前五排名
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<PurchaserAmountRankDTO> selectAmountRankByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据时间范围获取不同产地肉商接收数量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<PurchaserSaleAmountDTO> selectSaleAmountByTime(TimeRangeParam timeRangeParam);
}
