package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.PorkProduceDTO;
import com.ruoyi.app.DTO.SlaughterBatchDTO;
import com.ruoyi.app.DTO.SlaughterReportDTO;
import com.ruoyi.app.domain.SlaughterBatch;
import com.ruoyi.app.domain.request.ReqEntranceAndDistribute;
import com.ruoyi.app.domain.request.ReqSlaughterBatch;
import com.ruoyi.app.domain.request.ReqSlaughterReport;

/**
 * 屠宰批次Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface SlaughterBatchMapper 
{
    /**
     * 查询屠宰批次
     * 
     * @param id 屠宰批次主键
     * @return 屠宰批次
     */
    public SlaughterBatchDTO selectSlaughterBatchById(Long id);

    /**
     * 查询屠宰批次列表
     * 
     * @param slaughterBatch 屠宰批次
     * @return 屠宰批次集合
     */
    public List<SlaughterBatchDTO> selectSlaughterBatchList(ReqSlaughterBatch slaughterBatch);

    /**
     * 新增屠宰批次
     * 
     * @param slaughterBatch 屠宰批次
     * @return 结果
     */
    public int insertSlaughterBatch(SlaughterBatch slaughterBatch);

    /**
     * 修改屠宰批次
     * 
     * @param slaughterBatch 屠宰批次
     * @return 结果
     */
    public int updateSlaughterBatch(SlaughterBatch slaughterBatch);

    /**
     * 删除屠宰批次
     * 
     * @param id 屠宰批次主键
     * @return 结果
     */
    public int deleteSlaughterBatchById(Long id);

    /**
     * 批量删除屠宰批次
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSlaughterBatchByIds(Long[] ids);

    public int deleteSlaughterBatchByDistributeId(Long id);

    public int deleteSlaughterBatchByDistributeIds(Long[] ids);

    /**
     * 根据入场批次和分销批次ID获取各部位称重记录
     *
     * @param  reqEntranceAndDistribute 入场和分销批次信息
     * @return 结果
     */
    public List<PorkProduceDTO> selectPorkProduceByBatch(ReqEntranceAndDistribute reqEntranceAndDistribute);

    /**
     * 查询屠宰批次列表
     *
     * @param reqSlaughterReport 查询条件
     * @return 屠宰批次集合
     */
    public List<SlaughterReportDTO> selectSlaughterReport(ReqSlaughterReport reqSlaughterReport);
}
