package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.SupplierAmountRankDTO;
import com.ruoyi.app.DTO.SupplierOriginAmountDTO;
import com.ruoyi.app.domain.Supplier;
import com.ruoyi.app.domain.request.TimeRangeParam;

/**
 * 供应商Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface SupplierMapper 
{
    /**
     * 查询供应商
     * 
     * @param id 供应商主键
     * @return 供应商
     */
    public Supplier selectSupplierById(Long id);

    /**
     * 查询供应商列表
     * 
     * @param supplier 供应商
     * @return 供应商集合
     */
    public List<Supplier> selectSupplierList(Supplier supplier);

    /**
     * 查询全部供应商列表
     *
     *
     * @return 供应商集合
     */
    public List<Supplier> selectSupplierAll();


    /**
     * 新增供应商
     * 
     * @param supplier 供应商
     * @return 结果
     */
    public int insertSupplier(Supplier supplier);

    /**
     * 修改供应商
     * 
     * @param supplier 供应商
     * @return 结果
     */
    public int updateSupplier(Supplier supplier);

    /**
     * 删除供应商
     * 
     * @param id 供应商主键
     * @return 结果
     */
    public int deleteSupplierById(Long id);

    /**
     * 批量删除供应商
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSupplierByIds(Long[] ids);

    /**
     * 根据时间获取供应商数
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public Long selectCountByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据时间范围获取供应商供应数量前五排名
     *
     * @param timeRangeParam 时间
     * @return 供应商供应数量集合
     */
    public List<SupplierAmountRankDTO> selectAmountRankByTime(TimeRangeParam timeRangeParam);

    /**
     * 根据时间范围获取不同产地供应商供应数量
     *
     * @param timeRangeParam 时间
     * @return 结果
     */
    public List<SupplierOriginAmountDTO> selectOriginAmountByTime(TimeRangeParam timeRangeParam);

}
