package com.ruoyi.app.service;

import java.util.List;

import com.ruoyi.app.DTO.HookBindBatchListDTO;
import com.ruoyi.app.DTO.HookBindDetailDTO;
import com.ruoyi.app.domain.HookBind;

/**
 * 吊钩绑定Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IHookBindService 
{
    /**
     * 查询吊钩绑定
     * 
     * @param batchNo 批次号
     * @return 吊钩绑定
     */
    public HookBindBatchListDTO selectHookBindByBatch(String batchNo);

    /**
     * 查询吊钩绑定
     *
     * @param hookNo 批次号
     * @return 吊钩绑定
     */
    public HookBindDetailDTO selectHookBindDetail(String hookNo);

    /**
     * 查询吊钩绑定列表
     * 
     * @param hookBind 吊钩绑定
     * @return 吊钩绑定集合
     */
    public List<HookBind> selectHookBindList(HookBind hookBind);

    /**
     * 按批次查询吊钩绑定列表
     *
     * @param hookBind 吊钩绑定
     * @return 吊钩绑定集合
     */
    public List<HookBind> selectHookBindListByBatch(HookBind hookBind);
    /**
     * 校验相同时间吊钩是否已绑定
     *
     * @param  hookBind 吊钩绑定
     * @return 结果
     */
    public HookBind checkHookNoUnique(HookBind hookBind);

    /**
     * 新增吊钩绑定
     * 
     * @param hookBind 吊钩绑定
     * @return 结果
     */
    public int insertHookBind(HookBind hookBind);

    /**
     * 新增吊钩批量绑定
     *
     * @param batch 吊钩绑定
     * @return 结果
     */
    public int insertHookBindBatch(List<HookBind> batch);

    /**
     * 修改吊钩绑定
     * 
     * @param hookBind 吊钩绑定
     * @return 结果
     */
    public int updateHookBind(HookBind hookBind);

    /**
     * 批量删除吊钩绑定
     * 
     * @param ids 需要删除的吊钩绑定主键集合
     * @return 结果
     */
    public int deleteHookBindByIds(String[] ids);

    /**
     * 删除吊钩绑定信息
     * 
     * @param id 吊钩绑定主键
     * @return 结果
     */
    public int deleteHookBindById(String id);
}
