package com.ruoyi.app.service;

import java.util.List;

import com.ruoyi.app.domain.Pigpen;
import com.ruoyi.app.domain.SlaughterRelation;
import com.ruoyi.app.domain.request.ReqGetSlaughterRelation;
import com.ruoyi.app.domain.response.RespGetSlaughterRelation;

/**
 * 血码关系Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface ISlaughterRelationService 
{
    /**
     * 查询血码关系
     * 
     * @param id 血码关系主键
     * @return 血码关系
     */
    public SlaughterRelation selectSlaughterRelationById(Long id);

    /**
     * 查询血码关系列表
     * 
     * @param slaughterRelation 血码关系
     * @return 血码关系集合
     */
    public List<SlaughterRelation> selectSlaughterRelationList(SlaughterRelation slaughterRelation);

    /**
     * 查询血码关系列表
     *
     * @param req 查询条件
     * @return 供应商血码数量集合
     */
    public List<RespGetSlaughterRelation> selectSupplierList(ReqGetSlaughterRelation req);

    /**
     * 校验血码是否唯一
     *
     * @param  slaughterRelation 血码关系
     * @return 结果
     */
    public boolean checkCodeUnique(SlaughterRelation slaughterRelation);


    /**
     * 校验供应商的肉商是否唯一
     *
     * @param  slaughterRelation 血码关系
     * @return 结果
     */
    public SlaughterRelation checkPurchaserUnique(SlaughterRelation slaughterRelation);

    /**
     * 新增血码关系
     * 
     * @param slaughterRelation 血码关系
     * @return 结果
     */
    public int insertSlaughterRelation(SlaughterRelation slaughterRelation);

    /**
     * 批量新增血码关系
     *
     * @param list 血码关系
     * @return 结果
     */
    public int insertSlaughterRelationBatch(List<SlaughterRelation> list);

    /**
     * 修改血码关系
     * 
     * @param slaughterRelation 血码关系
     * @return 结果
     */
    public int updateSlaughterRelation(SlaughterRelation slaughterRelation);

    /**
     * 批量删除血码关系
     * 
     * @param ids 需要删除的血码关系主键集合
     * @return 结果
     */
    public int deleteSlaughterRelationByIds(Long[] ids);

    /**
     * 删除血码关系信息
     * 
     * @param id 血码关系主键
     * @return 结果
     */
    public int deleteSlaughterRelationById(Long id);
}
