package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.domain.Hook;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.app.mapper.DeadDisposalMapper;
import com.ruoyi.app.domain.DeadDisposal;
import com.ruoyi.app.service.IDeadDisposalService;

/**
 * 死淘处理方式Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-19
 */
@Service
public class DeadDisposalServiceImpl implements IDeadDisposalService 
{
    @Autowired
    private DeadDisposalMapper deadDisposalMapper;

    /**
     * 查询死淘处理方式
     * 
     * @param id 死淘处理方式主键
     * @return 死淘处理方式
     */
    @Override
    public DeadDisposal selectDeadDisposalById(Long id)
    {
        return deadDisposalMapper.selectDeadDisposalById(id);
    }

    /**
     * 查询死淘处理方式列表
     * 
     * @param deadDisposal 死淘处理方式
     * @return 死淘处理方式
     */
    @Override
    public List<DeadDisposal> selectDeadDisposalList(DeadDisposal deadDisposal)
    {
        return deadDisposalMapper.selectDeadDisposalList(deadDisposal);
    }

    /**
     * 校验吊钩名称是否唯一
     *
     * @param deadDisposal 吊钩
     * @return 结果
     */
    @Override
    public boolean checkDealReasonUnique(DeadDisposal deadDisposal)
    {
        Long id = StringUtils.isNull(deadDisposal.getId()) ? -1L : deadDisposal.getId();
        DeadDisposal info = deadDisposalMapper.checkDealReasonUnique(deadDisposal.getDealReason());
        if (StringUtils.isNotNull(info) && info.getId().longValue() != id.longValue())
        {
            return false;
        }
        return true;
    }

    /**
     * 新增死淘处理方式
     * 
     * @param deadDisposal 死淘处理方式
     * @return 结果
     */
    @Override
    public int insertDeadDisposal(DeadDisposal deadDisposal)
    {
        deadDisposal.setCreateTime(DateUtils.getNowDate());
        return deadDisposalMapper.insertDeadDisposal(deadDisposal);
    }

    /**
     * 修改死淘处理方式
     * 
     * @param deadDisposal 死淘处理方式
     * @return 结果
     */
    @Override
    public int updateDeadDisposal(DeadDisposal deadDisposal)
    {
        deadDisposal.setUpdateTime(DateUtils.getNowDate());
        return deadDisposalMapper.updateDeadDisposal(deadDisposal);
    }

    /**
     * 批量删除死淘处理方式
     * 
     * @param ids 需要删除的死淘处理方式主键
     * @return 结果
     */
    @Override
    public int deleteDeadDisposalByIds(Long[] ids)
    {
        return deadDisposalMapper.deleteDeadDisposalByIds(ids);
    }

    /**
     * 删除死淘处理方式信息
     * 
     * @param id 死淘处理方式主键
     * @return 结果
     */
    @Override
    public int deleteDeadDisposalById(Long id)
    {
        return deadDisposalMapper.deleteDeadDisposalById(id);
    }
}
