package com.ruoyi.app.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.app.domain.Hook;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.app.mapper.DryLossRatioMapper;
import com.ruoyi.app.domain.DryLossRatio;
import com.ruoyi.app.service.IDryLossRatioService;

/**
 * 干损比例Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-19
 */
@Service
public class DryLossRatioServiceImpl implements IDryLossRatioService 
{
    @Autowired
    private DryLossRatioMapper dryLossRatioMapper;

    /**
     * 查询干损比例
     * 
     * @param id 干损比例主键
     * @return 干损比例
     */
    @Override
    public DryLossRatio selectDryLossRatioById(Long id)
    {
        return dryLossRatioMapper.selectDryLossRatioById(id);
    }

    /**
     * 查询干损比例列表
     * 
     * @param dryLossRatio 干损比例
     * @return 干损比例
     */
    @Override
    public List<DryLossRatio> selectDryLossRatioList(DryLossRatio dryLossRatio)
    {
        return dryLossRatioMapper.selectDryLossRatioList(dryLossRatio);
    }

    /**
     * 校验是否存在重叠的时间范围
     *
     * @param dryLossRatio 干损比例
     * @return 结果
     */
    @Override
    public String checkTimeOverLap(DryLossRatio dryLossRatio)
    {
        List<DryLossRatio> info = dryLossRatioMapper.checkTimeOverLap(dryLossRatio);
        if (info == null || info.isEmpty())
        {
            return "";
        }
        // 拼接 id 字段
        return info.stream()
                .map(item -> String.valueOf(item.getId()))
                .collect(Collectors.joining(","));

    }

    /**
     * 获取满足当前时间的干损比
     *
     * @return 结果
     */
    @Override
    public DryLossRatio selectDryLossRatioNow()
    {
       return dryLossRatioMapper.selectDryLossRatioNow();

    }

    /**
     * 新增干损比例
     * 
     * @param dryLossRatio 干损比例
     * @return 结果
     */
    @Override
    public int insertDryLossRatio(DryLossRatio dryLossRatio)
    {
        dryLossRatio.setCreateTime(DateUtils.getNowDate());
        return dryLossRatioMapper.insertDryLossRatio(dryLossRatio);
    }

    /**
     * 修改干损比例
     * 
     * @param dryLossRatio 干损比例
     * @return 结果
     */
    @Override
    public int updateDryLossRatio(DryLossRatio dryLossRatio)
    {
        dryLossRatio.setUpdateTime(DateUtils.getNowDate());
        return dryLossRatioMapper.updateDryLossRatio(dryLossRatio);
    }

    /**
     * 批量删除干损比例
     * 
     * @param ids 需要删除的干损比例主键
     * @return 结果
     */
    @Override
    public int deleteDryLossRatioByIds(Long[] ids)
    {
        return dryLossRatioMapper.deleteDryLossRatioByIds(ids);
    }

    /**
     * 删除干损比例信息
     * 
     * @param id 干损比例主键
     * @return 结果
     */
    @Override
    public int deleteDryLossRatioById(Long id)
    {
        return dryLossRatioMapper.deleteDryLossRatioById(id);
    }
}
