package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.DTO.PorkSideProduceDTO;
import com.ruoyi.app.domain.request.ReqGetPorkSideProduce;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.app.mapper.PorkSideProduceMapper;
import com.ruoyi.app.domain.PorkSideProduce;
import com.ruoyi.app.service.IPorkSideProduceService;

/**
 * 白条生产记录Service业务层处理
 * 
 * @author coede
 * @date 2025-03-19
 */
@Service
public class PorkSideProduceServiceImpl implements IPorkSideProduceService 
{
    @Autowired
    private PorkSideProduceMapper porkSideProduceMapper;

    /**
     * 查询白条生产记录
     * 
     * @param id 白条生产记录主键
     * @return 白条生产记录
     */
    @Override
    public PorkSideProduceDTO selectPorkSideProduceById(Long id)
    {
        return porkSideProduceMapper.selectPorkSideProduceById(id);
    }

    /**
     * 查询白条生产记录列表
     * 
     * @param porkSideProduce 白条生产记录
     * @return 白条生产记录
     */
    @Override
    public List<PorkSideProduceDTO> selectPorkSideProduceList(ReqGetPorkSideProduce porkSideProduce)
    {
        return porkSideProduceMapper.selectPorkSideProduceList(porkSideProduce);
    }

    /**
     * 新增白条生产记录
     * 
     * @param porkSideProduce 白条生产记录
     * @return 结果
     */
    @Override
    public int insertPorkSideProduce(PorkSideProduce porkSideProduce)
    {
        porkSideProduce.setCreateTime(DateUtils.getNowDate());
        return porkSideProduceMapper.insertPorkSideProduce(porkSideProduce);
    }

    /**
     * 修改白条生产记录
     * 
     * @param porkSideProduce 白条生产记录
     * @return 结果
     */
    @Override
    public int updatePorkSideProduce(PorkSideProduce porkSideProduce)
    {
        porkSideProduce.setUpdateTime(DateUtils.getNowDate());
        return porkSideProduceMapper.updatePorkSideProduce(porkSideProduce);
    }

    /**
     * 批量删除白条生产记录
     * 
     * @param ids 需要删除的白条生产记录主键
     * @return 结果
     */
    @Override
    public int deletePorkSideProduceByIds(Long[] ids)
    {
        return porkSideProduceMapper.deletePorkSideProduceByIds(ids);
    }

    /**
     * 删除白条生产记录信息
     * 
     * @param id 白条生产记录主键
     * @return 结果
     */
    @Override
    public int deletePorkSideProduceById(Long id)
    {
        return porkSideProduceMapper.deletePorkSideProduceById(id);
    }
}
